@@ -16,7 +16,9 @@ Usage::
     session_client: DLMClient = session.client("dlm")
     ```
 """
-from mypy_boto3_dlm.client import DLMClient as Client, DLMClient
+from mypy_boto3_dlm.client import DLMClient
+
+Client = DLMClient
 
 
 __all__ = ("Client", "DLMClient")
